<div class="cal-month-day <%= cls %>">
	<span class="pull-right" data-cal-date="<%= data_day %>" data-cal-view="day" data-toggle="tooltip" title="<%= tooltip %>"><%= day %></span>
	<% if (events.length > 0) { %>
		<div class="events-list" data-cal-start="<%= start %>" data-cal-end="<%= end %>">
			<% _.each(events, function(event) { %>
				<a href="<%= event.url ? event.url : 'javascript:void(0)' %>" data-event-id="<%= event.id %>" data-event-class="<%= event['class'] %>"
					class="pull-left event <%= event['class'] %>" data-toggle="tooltip"
					title="<%= event.title %>"></a>
			<% }); %>
		</div>
	<% } %>
</div>
