<span class="pull-right" data-cal-date="<%= data_day %>" data-cal-view="month"><%= month_name %></span>
<% if (events.length > 0) { %>
	<small class="cal-events-num badge badge-important pull-left"><%= events.length %></small>
	<div class="hide events-list" data-cal-start="<%= start %>" data-cal-end="<%= end %>">
		<% _.each(events, function(event) { %>
			<a href="<%= event.url ? event.url : 'javascript:void(0)' %>" data-event-id="<%= event.id %>" data-event-class="<%= event['class'] %>"
				class="pull-left event <%= event['class'] %> event<%= event.id %>" data-toggle="tooltip"
				title="<%= event.title %>"></a>
		<% }); %>
	</div>
<% } %>
