<div class="cal-year-box">
	<div class="row row-fluid cal-before-eventlist">
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month1"><%= cal._month(0) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month2"><%= cal._month(1) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month3"><%= cal._month(2) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month4"><%= cal._month(3) %></div>
	</div>
	<div class="row row-fluid cal-before-eventlist">
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month1"><%= cal._month(4) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month2"><%= cal._month(5) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month3"><%= cal._month(6) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month4"><%= cal._month(7) %></div>
	</div>
	<div class="row row-fluid cal-before-eventlist">
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month1"><%= cal._month(8) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month2"><%= cal._month(9) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month3"><%= cal._month(10) %></div>
		<div class="span3 col-md-3 cal-cell" data-cal-row="-month4"><%= cal._month(11) %></div>
	</div>
</div>
