if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['it-IT'] = {
	error_noview:     'Calendario: vista {0} non trovata',
	error_dateformat: 'Calendario: formato data {0} non valido. Dovrebbe essere "now" o "yyyy-mm-dd"',
	error_loadurl:    'Calendario: URL di caricamento degli eventi non impostato',
	error_where:      'Calendario: direzione di spostamento {0} non valida. I valori validi sono "next" o "prev" o "today"',
	error_timedevide: 'Calendario: Il divisore del tempo deve poter dividere 60 in un numero intero. Per esempio 10, 15, 30',

	no_events_in_day: 'Nessun evento in questo giorno.',

	title_year:  'Anno {0}',
	title_month: '{0} {1}',
	title_week:  'Settimana {0} del {1}',
	title_day:   '{0} {1} {2} {3}',

	week:        'Settimana {0}',
	all_day:     'Tutto il giorno',
	time:        'Ora',
	events:      'Eventi',
	before_time: 'Evento antecedente',
	after_time:  'Evento che prosegue',

	m0:  'Gennaio',
	m1:  'Febbraio',
	m2:  'Marzo',
	m3:  'Aprile',
	m4:  'Maggio',
	m5:  'Giugno',
	m6:  'Luglio',
	m7:  'Agosto',
	m8:  'Settembre',
	m9:  'Ottobre',
	m10: 'Novembre',
	m11: 'Dicembre',

	ms0:  'Gen',
	ms1:  'Feb',
	ms2:  'Mar',
	ms3:  'Apr',
	ms4:  'Mag',
	ms5:  'Giu',
	ms6:  'Lug',
	ms7:  'Ago',
	ms8:  'Set',
	ms9:  'Ott',
	ms10: 'Nov',
	ms11: 'Dic',

	d0: 'Domenica',
	d1: 'Lunedì',
	d2: 'Martedì',
	d3: 'Mercoledì',
	d4: 'Giovedì',
	d5: 'Venerdì',
	d6: 'Sabato',

	first_day: 1,

	holidays: {
		'01-01':    'Capodanno',
		'06-01':    'Epifania',
		'easter':   'Pasqua',
		'easter+1': 'Lunedì dell’Angelo',
		'25-04':    'Festa della Liberazione',
		'01-05':    'Festa del Lavoro',
		'02-06':    'Festa della Repubblica',
		'15-08':    'Ferragosto',
		'01-11':    'Ognissanti',
		'08-12':    'Immacolata Concezione',
		'25-12':    'Natale',
		'26-12':    'Santo Stefano'
	}
};
