# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-08-09 11:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CalendarEvent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('url', models.URLField(blank=True, null=True, verbose_name='URL')),
                ('css_class', models.CharField(blank=True, choices=[(b'', 'Normal'), (b'event-warning', 'Warning'), (b'event-info', 'Info'), (b'event-success', 'Success'), (b'event-inverse', 'Inverse'), (b'event-special', 'Special'), (b'event-important', 'Important')], max_length=20, verbose_name='CSS Class')),
                ('start', models.DateTimeField(verbose_name='Start Date')),
                ('end', models.DateTimeField(blank=True, null=True, verbose_name='End Date')),
            ],
        ),
    ]
