if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['el-GR'] = {
	error_noview:     'Ημερολόγιο: Η προβολή {0} δεν βρέθηκε',
	error_dateformat: 'Ημερολόγιο: Η μορφή της ημερομηνίας {0} δεν είναι έγκυρη. Παρακαλώ χρησιμοποιήστε "now" ή "yyyy-mm-dd"',
	error_loadurl:    'Ημερολόγιο: Η διεύθυνση λήψης των event δεν έχει καθοριστεί',
	error_where:      'Ημερολόγιο: Η μορφή κατεύθυνσης {0} δεν είναι έγκυρη. Παρακαλώ χρησιμοποιήστε μία εκ των "next", "prev" και "today"',
	error_timedevide: 'Ημερολόγιο: παράμετρος στο διαχωριστή χρόνου πρέπει να διαιρέσει το 60 με έναν ακέραιο αριθμό. Για παράδειγμα 10, 15, 30',

	no_events_in_day: 'Δεν υπάρχουν καταχωρήσεις σε αυτήν την ημέρα.',

	title_year:  'Έτος {0}',
	title_month: '{0} {1}',
	title_week:  'Εβδομάδα {0} του έτους {1}',
	title_day:   '{0} {1} {2} {3}',

	week:        'Εβδομάδα {0}',
	all_day:     'Όλη την ημέρα',
	time:        'χρόνος',
	events:      'εξελίξεις',
	before_time: 'Ώρα πριν από το τέλος της ταινίας',
	after_time:  'Τερματισμός μετά από μια προσωρινή ταινία',

	m0:  'Ιανουάριος',
	m1:  'Φεβρουάριος',
	m2:  'Μάρτιος',
	m3:  'Απρίλιος',
	m4:  'Μάϊος',
	m5:  'Ιούνιος',
	m6:  'Ιούλιος',
	m7:  'Αύγουστος',
	m8:  'Σεπτέμβριος',
	m9:  'Οκτώβριος',
	m10: 'Νοέμβριος',
	m11: 'Δεκέμβριος',

	ms0:  'Ιαν',
	ms1:  'Φεβ',
	ms2:  'Μαρ',
	ms3:  'Απρ',
	ms4:  'Μαϊ',
	ms5:  'Ιουν',
	ms6:  'Ιουλ',
	ms7:  'Αυγ',
	ms8:  'Σεπ',
	ms9:  'Οκτ',
	ms10: 'Νοε',
	ms11: 'Δεκ',

	d0: 'Κυριακή',
	d1: 'Δευτέρα',
	d2: 'Τρίτη',
	d3: 'Τετάρτη',
	d4: 'Πέμπτη',
	d5: 'Παρασκευή',
	d6: 'Σάββατο',

	easter:       'Πάσχα',
	easterMonday: 'Δευτέρα του Πάσχα',

	first_day: 2,

	holidays: {
		'01-01':     "Πρωτοχρονιά",
		'06-01':     "Θεοφάνεια",
		'easter-41': "Καθαρά Δευτέρα",
		'23-03':     "Εικοστή Πέμπτη Μαρτιου",
		'easter-2':  "Μεγάλη Παρασκευή",
		'easter':    "Κυριακή του Πάσχα",
		'easter+1':  "Δευτέρα του Πάσχα",
		'01-05':     "Εργατική Πρωτομαγιά",
		'easter+49': "Πεντηκοστή",
		'easter+50': "Αγίου Πνεύματος",
		'15-08':     "Η Κοίμηση της Θεοτόκου",
		'28-10':     "Ημέρα του Όχι",
		'25-12':     "Χριστούγεννα",
		'26-12':     "Σύναξις Ὑπεραγίας Θεοτόκου Μαρίας"
	}
};
