
if(!window.calendar_languages) {
	window.calendar_languages = {};
}

window.calendar_languages['tr-TR'] = {
	error_noview: 'Takvim: Görünüm {0} bulunamadı',
	error_dateformat: 'Takvim: Yanlış tarih formatı {0}. Şunlardan biri olmalı "now" veya "yyyy-mm-dd"',
	error_loadurl: 'Takvim: Etkinlik bağlantısı belirtilmemiş',
	error_where: 'Takvim: Yanlış gezinme yönü {0}. Sadece bunlardan biri olabilir "next" veya "prev" veya "today"',
	error_timedevide: 'Takvim: Zaman bölme parametresi 60\'ı kalansız bölmelidir. 10, 15, 30 gibi',

	no_events_in_day: 'Bugün etkinlik yok',

	title_year: '{0}',
	title_month: '{0} {1}',
	title_week: '{1} {0}. Hafta',
	title_day: '{0} {1} {2}, {3}',

	week:        '{0}. Hafta',
	all_day:     'Tüm gün',
	time:        'Zaman',
	events:      'Etkinlikler',
	before_time: 'Zamanından önce biter',
	after_time:  'Zamanından sonra başlar',

	m0: 'Ocak',
	m1: 'Şubat',
	m2: 'Mart',
	m3: 'Nisan',
	m4: 'Mayıs',
	m5: 'Haziran',
	m6: 'Temmuz',
	m7: 'Ağustos',
	m8: 'Eylül',
	m9: 'Ekim',
	m10: 'Kasım',
	m11: 'Aralık',

	ms0: 'Oca',
	ms1: 'Şub',
	ms2: 'Mar',
	ms3: 'Nis',
	ms4: 'May',
	ms5: 'Haz',
	ms6: 'Tem',
	ms7: 'Ağu',
	ms8: 'Eyl',
	ms9: 'Eki',
	ms10: 'Kas',
	ms11: 'Ara',

	d0: 'Pazar',
	d1: 'Pazartesi',
	d2: 'Salı',
	d3: 'Çarşamba',
	d4: 'Perşembe',
	d5: 'Cuma',
	d6: 'Cumartesi',

	first_day: 1,

	holidays: {
		'01-01' : 'Yılbaşı',
		'23-04' : 'Ulusal Egemenlik ve Çocuk Bayramı',
		'01-05' : 'İşçi Bayramı',
		'19-05' : 'Atatürk\'ü Anma, Gençlik ve Spor Bayramı',
		'30-08' : 'Zafer Bayramı',
		'29-10' : 'Cumhuriyet Bayramı'
	}
};