if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['es-ES'] = {
	error_noview:     'Calendario: Vista {0} no encontrada',
	error_dateformat: 'Calendario: Formato de fecha inválido {0}. Debe ser "now" o "yyyy-mm-dd"',
	error_loadurl:    'Calendario: URL de carga de eventos no configurada',
	error_where:      'Calendario: Dirección de navegación incorrecta {0}. Los valores correctos son "next" o "prev" o "today"',
	error_timedevide: 'Calendario: parámetro para el separador de hora debe dividir 60 por un entero. Por ejemplo 10, 15, 30',

	no_events_in_day: 'No hay eventos hoy',

	title_year:  'Año {0}',
	title_month: '{0} {1}',
	title_week:  'Semana {0} del {1}',
	title_day:   '{0} {1} {2} {3}',

	week:        'Semana {0}',
	all_day:     'Todo el día',
	time:        'Tiempo',
	events:      'Desarrollos',
	before_time: 'Tiempo antes de la cinta final',
	after_time:  'Fin después de una cinta temporal',

	m0:  'Enero',
	m1:  'Febrero',
	m2:  'Marzo',
	m3:  'Abril',
	m4:  'Mayo',
	m5:  'Junio',
	m6:  'Julio',
	m7:  'Agosto',
	m8:  'Septiembre',
	m9:  'Octubre',
	m10: 'Noviembre',
	m11: 'Diciembre',

	ms0:  'Ene',
	ms1:  'Feb',
	ms2:  'Mar',
	ms3:  'Abr',
	ms4:  'May',
	ms5:  'Jun',
	ms6:  'Jul',
	ms7:  'Ago',
	ms8:  'Sep',
	ms9:  'Oct',
	ms10: 'Nov',
	ms11: 'Dic',

	d0: 'Domingo',
	d1: 'Lunes',
	d2: 'Martes',
	d3: 'Miércoles',
	d4: 'Jueves',
	d5: 'Viernes',
	d6: 'Sábado',

	easter:       'Pascuas',
	easterMonday: 'Lunes de Pascuas',

	first_day: 1,

	holidays: {
		'01-01':    "Año Nuevo",
		'06-01':    "Día de Reyes",
		'19-03':    "San José",
		'easter-3': "Jueves Santo",
		'easter-2': "Viernes Santo",
		'easter':   "Pascua",
		'easter+1': "Lunes de Pascua",
		'01-05':    "Día del Trabajador",
		'15-08':    "Asunción",
		'12-10':    "Fiesta Nacional de España",
		'01-11':    "Día de todos los Santos",
		'06-12':    "Día de la Constitución",
		'08-12':    "Inmaculada Concepción",
		'25-12':    "Navidad"
	}
};
