if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['sv-SE'] = {
	error_noview:     'Kalender: Vy {0} ej funnen',
	error_dateformat: 'Kalender: Felaktigt datumformat {0}. Måste antingen vara "now" eller "åååå-mm-dd"',
	error_loadurl:    'Kalender: Laddnings-URL för events är ej satt',
	error_where:      'Kalender: Felaktig navigeringsriktning {0}. Kan endast vara "next", "prev" eller "today"',
	error_timedevide: 'Kalender: parameter till tidsavgränsare måste dela 60 med ett heltal. Till exempel 10, 15, 30',

	title_year:  'År {0}',
	title_month: '{0} år {1}',
	title_week:  '{0} vecka år {1}',
	title_day:   '{0} {1} {2} år {3}',

	week:        'Vecka {0}',
	all_day:     'Hela dagen',
	time:        'Tid',
	events:      'Utvecklingen',
	before_time: 'Tid före utgången bandet',
	after_time:  'Avsluta efter ett tillfälligt band',

	m0:  'Januari',
	m1:  'Februari',
	m2:  'Mars',
	m3:  'April',
	m4:  'Maj',
	m5:  'Juni',
	m6:  'Juli',
	m7:  'Augusti',
	m8:  'September',
	m9:  'Oktober',
	m10: 'November',
	m11: 'December',

	ms0:  'Jan',
	ms1:  'Feb',
	ms2:  'Mar',
	ms3:  'Apr',
	ms4:  'Maj',
	ms5:  'Jun',
	ms6:  'Jul',
	ms7:  'Aug',
	ms8:  'Sep',
	ms9:  'Okt',
	ms10: 'Nov',
	ms11: 'Dec',

	d0: 'Söndag',
	d1: 'Måndag',
	d2: 'Tisdag',
	d3: 'Onsdag',
	d4: 'Torsdag',
	d5: 'Fredag',
	d6: 'Lördag',

	easter:       'Påsk',
	easterMonday: 'Påskmåndagen',

	first_day: 1,

	holidays: {
		'01-01':     "Nyårsdagen",
		'06-01':     "Trettondedag jul",
		'easter-2':  "Långfredagen",
		'easter':    "Påskdagen",
		'easter+1':  "Annandag påsk",
		'01-05':     "Första maj",
		'easter+39': "Kristi himmelsfärdsdag",
		'easter+49': "Pingstdagen",
		'06-06':     "Sveriges nationaldag",
		'25-12':     "Juldagen",
		'26-12':     "Annandag jul"
	}
};
