if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['sv-SE'] = {
	error_noview:     'Kalender: {0} ble ikke funnet',
	error_dateformat: 'Kalender: Feil datoformat {0}. Må være "now" eller "åååå-mm-dd"',
	error_loadurl:    'Kalender: urlen for events er ikke satt',
	error_where:      'Kalender: Feil navigeringsrettning {0}. Kan kun være "next", "prev" eller "today"',
	error_timedevide: 'Kalender: parameter for tidsavgrensning må dele 60 med et heltall. Til eksempel 10, 15, 30',

	title_year:  'År {0}',
	title_month: '{0} år {1}',
	title_week:  '{0} uke år {1}',
	title_day:   '{0} {1} {2} år {3}',

	week:        'Uke {0}',
	all_day:     'Hele dagen',
	time:        'Tid',
	events:      'Event',
	before_time: 'Avsluttes før tidslinjen',
	after_time:  'Starter etter tidslinjen',

	m0:  'Januar',
	m1:  'Februar',
	m2:  'Mars',
	m3:  'April',
	m4:  'Mai',
	m5:  'Juni',
	m6:  'Juli',
	m7:  'August',
	m8:  'September',
	m9:  'Oktober',
	m10: 'November',
	m11: 'December',

	ms0:  'Jan',
	ms1:  'Feb',
	ms2:  'Mar',
	ms3:  'Apr',
	ms4:  'Mai',
	ms5:  'Jun',
	ms6:  'Jul',
	ms7:  'Aug',
	ms8:  'Sep',
	ms9:  'Okt',
	ms10: 'Nov',
	ms11: 'Dec',

	d0: 'Søndag',
	d1: 'Mandag',
	d2: 'Tirsdag',
	d3: 'Onsdag',
	d4: 'Torsdag',
	d5: 'Fredag',
	d6: 'Lørdag',

	easter:       'Påske',
	easterMonday: 'Første påskedag',

	first_day: 1,

	holidays: {
	}
};
