{% load static %}
<script src="{% static 'js/calendar.js' %}"></script>
<script src="{% static 'js/underscore-min.js' %}"></script>
{% if language %}
<script src="{% get_static_prefix %}js/language/{{ language }}.js"></script>
{% endif %}
