if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['de-AT'] = {
	error_noview:     'Kalender: Ansicht {0} nicht gefunden',
	error_dateformat: 'Kalender: Falsches Datumsformat {0}. Sollte entweder "now" oder "yyyy-mm-dd" sein',
	error_loadurl:    'Kalender: Event-URL nicht gesetzt.',
	error_where:      'Kalender: Falsche Navigationsrichtung {0}. Nur "next", "prev" oder "today" sind erlaubt',
	error_timedevide: 'Kalender: Parameter für die Zeiteinteilung muss ein Teiler von 60 sein. Beispielsweise 10, 15, 30',

	no_events_in_day: 'Keine Ereignisse an diesem Tag.',

	title_year:  '{0}',
	title_month: '{0} {1}',
	title_week:  'Woche {0} im Jahr {1}',
	title_day:   '{0}, der {1}. {2} {3}',

	week:        'Woche {0}',
	all_day:     'Ganzen Tag',
	time:        'Zeit',
	events:      'Ereignisse',
	before_time: 'Endet vor Zeitspanne',
	after_time:  'Beginnt nach Zeitspanne',

	m0:  'Jänner',
	m1:  'Februar',
	m2:  'März',
	m3:  'April',
	m4:  'Mai',
	m5:  'Juni',
	m6:  'Juli',
	m7:  'August',
	m8:  'September',
	m9:  'Oktober',
	m10: 'November',
	m11: 'Dezember',

	ms0:  'Jan',
	ms1:  'Feb',
	ms2:  'Mär',
	ms3:  'Apr',
	ms4:  'Mai',
	ms5:  'Jun',
	ms6:  'Jul',
	ms7:  'Aug',
	ms8:  'Sep',
	ms9:  'Okt',
	ms10: 'Nov',
	ms11: 'Dez',

	d0: 'Sonntag',
	d1: 'Montag',
	d2: 'Dienstag',
	d3: 'Mittwoch',
	d4: 'Donnerstag',
	d5: 'Freitag',
	d6: 'Samstag',

	first_day: 1,

	holidays: {
		'01-01':     'Neujahr',
		'06-01':     'Heilige Drei Könige',
		'easter-2':  'Karfreitag',
		'easter+1':  'Ostermontag',
		'01-05':     'Staatsfeiertag',
		'easter+39': 'Christi Himmelfahrt',
		'easter+49': 'Pfingstsonntag',
		'easter+50': 'Pfingstmontag',
		'15-08':     'Mariä Himmelfahrt',
		'26-10':     'Nationalfeiertag',
		'01-11':     'Allerheiligen',
		'08-12':     'Mariä Empfängnis',
		'24-12':     'Heiliger Abend',
		'25-12':     'Weihnachten',
		'26-12':     'Stefanitag',
		'31-12':     'Silvester',
	}
};
