if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['pl-PL'] = {
	error_noview:     'Kalendarz: Widok {0} nie znaleziony',
	error_dateformat: 'Kalendarz: Zły format daty {0}. Powinna być w formacie "now" lub "yyyy-mm-dd"',
	error_loadurl:    'Kalendarz: Adres URL do ładowania wydarzeń nie ustawiony',
	error_where:      'Kalendarz: Zły kierunek nawigacji {0}. Może być tylko "następny" or "poprzedni" or "dzisiaj"',
	error_timedevide: 'Kalendarz: parametr do separatora czasu należy podzielić 60 przez liczbę całkowitą. Na przykład 10, 15, 30',

	title_year:  'Rok {0}',
	title_month: '{0} rok {1}',
	title_week:  '{0} tydzień roku {1}',
	title_day:   '{0} {1} {2} rok {3}',

	week:        'Tydzień {0}',
	all_day:     'Cały dzień',
	time:        'Czas',
	events:      'Rozwój',
	before_time: 'Czasu, zanim taśma koniec',
	after_time:  'Kończy się po taśmie tymczasowej',

	m0:  'Styczeń',
	m1:  'Luty',
	m2:  'Marzec',
	m3:  'Kwiecień',
	m4:  'Maj',
	m5:  'Czerwiec',
	m6:  'Lipiec',
	m7:  'Sierpień',
	m8:  'Wrzesień',
	m9:  'Październik',
	m10: 'Listopad',
	m11: 'Grudzień',

	ms0:  'Sty',
	ms1:  'Lut',
	ms2:  'Mar',
	ms3:  'Kwi',
	ms4:  'Maj',
	ms5:  'Cze',
	ms6:  'Lip',
	ms7:  'Sie',
	ms8:  'Wrz',
	ms9:  'Paź',
	ms10: 'Lis',
	ms11: 'Gru',

	d0: 'Niedziela',
	d1: 'Poniedziałek',
	d2: 'Wtorek',
	d3: 'Środa',
	d4: 'Czwartek',
	d5: 'Piątek',
	d6: 'Sobota',

	easter:       'Wielkanoc',
	easterMonday: 'Poniedziałek wielkanocny',

	first_day: 1,

	holidays: {
		'01-01':     "Nowy Rok",
		'06-01':     "Trzech Króli",
		'easter':    "Niedziela Wielkanocna",
		'easter+1':  "Poniedziałek Wielkanocny",
		'01-05':     "Święto Pracy",
		'03-05':     "Święto Konstytucji Trzeciego Maja",
		'easter+49': "Zielone Świątki",
		'easter+60': "Boże Ciało",
		'15-08':     "Wniebowzięcie Najświętszej Maryi Panny",
		'01-11':     "Wszystkich Świętych",
		'11-11':     "Dzień Niepodległości",
		'25-12':     "Pierwszy dzień Bożego Narodzenia",
		'26-12':     "Drugi dzień Bożego Narodzenia"
	}
};
