if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['da-DK'] = {
	error_noview: 'Kalender: View {0} ikke fundet',
	error_dateformat: 'Kalender: Forkert dato format {0}. Det skal enten være "now" eller "åååå-mm-dd"',
	error_loadurl: 'Kalender: Aktivitet URL ikke angivet',
	error_where: 'Kalender: Forkert navigering {0}. Du kan kun bruge "next" eller "prev" eller "today"',
	error_timedevide: 'Kalender: Time split parameter skal være dividerbart med 60 uden decimaler. Noget ala 10, 15, 30',

	no_events_in_day: 'Ingen aktiviteret på denne dag.',

	title_year: '{0}',
	title_month: '{0} {1}',
	title_week: 'uge {0} af {1}',
	title_day: '{0} {1} {2}, {3}',

	week:'Uge {0}',
	all_day:     'Hele dagen',
	time:        'Time',
	events:      'Aktivitet',
	before_time: 'Slutter før tidslinje',
	after_time:  'Starter efer tidslinje',

	m0: 'Januar',
	m1: 'Februar',
	m2: 'Marst',
	m3: 'April',
	m4: 'Maj',
	m5: 'Juni',
	m6: 'Juli',
	m7: 'August',
	m8: 'September',
	m9: 'Oktober',
	m10: 'November',
	m11: 'December',

	ms0: 'Jan',
	ms1: 'Feb',
	ms2: 'Mar',
	ms3: 'Apr',
	ms4: 'Maj',
	ms5: 'Jun',
	ms6: 'Jul',
	ms7: 'Aug',
	ms8: 'Sep',
	ms9: 'Okt',
	ms10: 'Nov',
	ms11: 'Dec',

	d0: 'Søndag',
	d1: 'Mandag',
	d2: 'Tirsdag',
	d3: 'Onsdag',
	d4: 'Torsdag',
	d5: 'Fredag',
	d6: 'Lørdag',

	first_day: 1,

	holidays: {
	  '01-01':'Nytårsdag',
	  'easter-3':'Skærtorsdag',
	  'easter-2':'Langfredag',
	  'easter':'Påskedag',
	  'easter+1':'2. Påskedag',
	  'easter+26':'Store bededag',
	  'easter+39':'Kristi himmelfartsdag',
	  'easter+49':'Pinsedag',
	  'easter+50':'2. Pinsedag',
	  '25-12':'Juledag',
	  '26-12':'2. Juledag',
	}
};
